==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AQuotedClassName.h <==
// public final class soot.jimple.parser.node.AQuotedClassName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b95a29e74c2391a0 soot_jimple_parser_node_AQuotedClassName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5677865048a744c3 soot_jimple_parser_node_PClassName

// header file dependencies
// @dep_header soot_jimple_parser_node_PClassName

#include "soot/jimple/parser/node/PClassName.h"

#ifndef _JC_soot_jimple_parser_node_AQuotedClassName_H_
#define _JC_soot_jimple_parser_node_AQuotedClassName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TQuotedName$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$sub_refs	_jc_soot_jimple_parser_node_AQuotedClassName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$sub_nonrefs	_jc_soot_jimple_parser_node_AQuotedClassName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$refs	_jc_soot_jimple_parser_node_AQuotedClassName$refs;
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$nonrefs	_jc_soot_jimple_parser_node_AQuotedClassName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$object	_jc_soot_jimple_parser_node_AQuotedClassName$object;

typedef const struct _jc_soot_jimple_parser_node_AQuotedClassName$vmethods	_jc_soot_jimple_parser_node_AQuotedClassName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AQuotedClassName$vtable	_jc_soot_jimple_parser_node_AQuotedClassName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AQuotedClassName$vtype	_jc_soot_jimple_parser_node_AQuotedClassName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$_init$0d1be0f2915bd2a4(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AQuotedClassName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);
extern struct _jc_soot_jimple_parser_node_TQuotedName$object *_jc_soot_jimple_parser_node_AQuotedClassName$method$getQuotedName$c1052124678e1334(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$setQuotedName$191e6d0cc56dd3f2(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AQuotedClassName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$getQuotedName$c1052124678e1334;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$setQuotedName$191e6d0cc56dd3f2;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AQuotedClassName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);
	struct _jc_soot_jimple_parser_node_TQuotedName$object	*(*getQuotedName$c1052124678e1334)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setQuotedName$191e6d0cc56dd3f2)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AQuotedClassName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PClassName$vmethods	soot_jimple_parser_node_PClassName;
	_jc_soot_jimple_parser_node_AQuotedClassName$vmethods	soot_jimple_parser_node_AQuotedClassName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AQuotedClassName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AQuotedClassName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AQuotedClassName$sub_refs {
	struct _jc_soot_jimple_parser_node_TQuotedName$object	*__5fquotedName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AQuotedClassName$refs {
    _jc_soot_jimple_parser_node_AQuotedClassName$sub_refs	soot_jimple_parser_node_AQuotedClassName;
    _jc_soot_jimple_parser_node_PClassName$sub_refs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AQuotedClassName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AQuotedClassName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PClassName$sub_nonrefs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_AQuotedClassName$sub_nonrefs	soot_jimple_parser_node_AQuotedClassName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AQuotedClassName$object {
	_jc_soot_jimple_parser_node_AQuotedClassName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AQuotedClassName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AQuotedClassName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AQuotedClassName$vtype _jc_soot_jimple_parser_node_AQuotedClassName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AQuotedClassName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AQuotedClassName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AQuotedClassName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AQuotedClassName.h <==
// public final class soot.jimple.parser.node.AQuotedClassName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b95a29e74c2391a0 soot_jimple_parser_node_AQuotedClassName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5677865048a744c3 soot_jimple_parser_node_PClassName

// header file dependencies
// @dep_header soot_jimple_parser_node_PClassName

#include "soot/jimple/parser/node/PClassName.h"

#ifndef _JC_soot_jimple_parser_node_AQuotedClassName_H_
#define _JC_soot_jimple_parser_node_AQuotedClassName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TQuotedName$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$sub_refs	_jc_soot_jimple_parser_node_AQuotedClassName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$sub_nonrefs	_jc_soot_jimple_parser_node_AQuotedClassName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$refs	_jc_soot_jimple_parser_node_AQuotedClassName$refs;
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$nonrefs	_jc_soot_jimple_parser_node_AQuotedClassName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AQuotedClassName$object	_jc_soot_jimple_parser_node_AQuotedClassName$object;

typedef const struct _jc_soot_jimple_parser_node_AQuotedClassName$vmethods	_jc_soot_jimple_parser_node_AQuotedClassName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AQuotedClassName$vtable	_jc_soot_jimple_parser_node_AQuotedClassName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AQuotedClassName$vtype	_jc_soot_jimple_parser_node_AQuotedClassName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$_init$0d1be0f2915bd2a4(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AQuotedClassName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TQuotedName$object *_jc_soot_jimple_parser_node_AQuotedClassName$method$getQuotedName$c1052124678e1334(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AQuotedClassName$method$setQuotedName$191e6d0cc56dd3f2(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AQuotedClassName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$getQuotedName$c1052124678e1334;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$setQuotedName$191e6d0cc56dd3f2;
extern _jc_method _jc_soot_jimple_parser_node_AQuotedClassName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AQuotedClassName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TQuotedName$object	*(*getQuotedName$c1052124678e1334)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setQuotedName$191e6d0cc56dd3f2)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *, struct _jc_soot_jimple_parser_node_TQuotedName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AQuotedClassName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PClassName$vmethods	soot_jimple_parser_node_PClassName;
	_jc_soot_jimple_parser_node_AQuotedClassName$vmethods	soot_jimple_parser_node_AQuotedClassName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AQuotedClassName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AQuotedClassName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AQuotedClassName$sub_refs {
	struct _jc_soot_jimple_parser_node_TQuotedName$object	*__5fquotedName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AQuotedClassName$refs {
    _jc_soot_jimple_parser_node_AQuotedClassName$sub_refs	soot_jimple_parser_node_AQuotedClassName;
    _jc_soot_jimple_parser_node_PClassName$sub_refs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AQuotedClassName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AQuotedClassName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PClassName$sub_nonrefs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_AQuotedClassName$sub_nonrefs	soot_jimple_parser_node_AQuotedClassName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AQuotedClassName$object {
	_jc_soot_jimple_parser_node_AQuotedClassName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AQuotedClassName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AQuotedClassName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AQuotedClassName$vtype _jc_soot_jimple_parser_node_AQuotedClassName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AQuotedClassName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AQuotedClassName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AQuotedClassName_H_ */
